==> rec10%200.9.4.2.tar.bz2: rec10 0.9.4.2/rec10/recdblist.py <==
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009-2010 Yukikaze

"""
task names
"""
import os
import os.path

global REC_RESERVE
global REC_FINAL_RESERVE
global REC_ENCODE_GRID
global REC_ENCODE_LOCAL
global REC_ENCODE_QUE
global REC_MISS_ENCODE
global REC_KEYWORD
global REC_KEYWORD_EVERY_SOME_DAYS
global REC_FIN_LOCAL
global REC_MISS_DECODE
global REC_TS_DECODE_QUE
global REC_TS_DECODING
global REC_TS_RECORDING
global REC_AVI_TO_MKV
global REC_AVI_TO_MP4
global REC_MKV_TO_MP4
global REC_CHANGING_CANTAINER

#ここから処理のちに移動

global REC_MOVE_END

#ここから自動で提起される処理。
global REC_AUTO_SUGGEST_REC
global REC_AUTO_SUGGEST_DECODE
global REC_AUTO_SUGGEST_ENCODE
global REC_AUTO_SUGGEST_AVI2MP4
global REC_AUTO_SUGGEST_MKV2MP4
global REC_AUTO_SUGGEST_AVI2FP
global REC_AUTO_SUGGEST_AP2FP
global REC_BAYES_SUGGEST
global REC_AUTO_KEYWORD
REC_RESERVE = "reserve_flexible"
REC_FINAL_RESERVE = "reserve_fixed"
REC_ENCODE_GRID = "convert_ts_mp4_network"
REC_ENCODE_LOCAL = "convert_ts_mp4_running"
REC_ENCODE_QUE = "convert_ts_mp4"
REC_MISS_ENCODE = "convert_avi_mp4_miss"
REC_KEYWORD = "search_today"
REC_KEYWORD_EVERY_SOME_DAYS = "search_everyday"
REC_FIN_LOCAL = "convert_ts_mp4_finished"
REC_MISS_DECODE = "convert_b25_ts_miss"
REC_TS_DECODE_QUE = "convert_b25_ts"
REC_TS_DECODING = "convert_b25_ts_running"
REC_TS_RECORDING = "reserve_running"
REC_CHANGING_CANTAINER = "convert_mkv_mp4_runnings"
REC_AVI_TO_MKV = "convert_avi_mkv"
REC_AVI_TO_MP4 = "convert_avi_mp4"
REC_MKV_TO_MP4 = "convert_mkv_mp4"

REC_MOVE_END = "move_end"

REC_AUTO_SUGGEST_REC = "auto_suggest_rec"
REC_AUTO_SUGGEST_DECODE = "auto_suggest_dec"
REC_AUTO_SUGGEST_ENCODE = "auto_suggest_enc"
REC_AUTO_SUGGEST_AVI2FP = "auto_suggest_avi2fp"
REC_AUTO_SUGGEST_AP2FP = "auto_suggest_ap2fp"
REC_AUTO_KEYWORD = "auto_keyword"
REC_BAYES_SUGGEST ="bayes_suggest"

version = 94
def printutf8(unicode):
    str=unicode.encode('utf-8')
    print str
    logfname="/var/log/rec10"
    mode="a"
    if os.path.exists(logfname):
        f=open(logfname,mode)
        f.write(str+"\n")
        f.close()
def addlog(tspath,txt,log_title):
    logo=tspath
    logo=logo.replace("_1.wav",".ts")
    logo=logo.replace("_2.wav",".ts")
    logo=logo.replace("_1.aac",".ts")
    logo=logo.replace("_2.aac",".ts")
    logo=logo.replace("_1.mp3",".ts")
    logo=logo.replace("_2.mp3",".ts")
    logo=logo.replace(".ts.tsmix",".ts")
    logo=logo.replace(".ts.b25",".ts")
    logo=logo.replace(".sa.avi",".ts")
    logo=logo.replace(".m2v",".ts")
    logo=logo.replace(".avi",".ts")
    logo=logo.replace(".mkv",".ts")
    logo=logo.replace(".wav",".ts")
    logo=logo.replace(".mp4",".ts")
    logo=logo.replace(".mp3",".ts")
    logo=logo.replace(".aac",".ts")
    logo=logo.replace(".srt",".ts")
    logo=logo.replace(".ts",".log")
    f=open(logo,'a')
    s=len(txt)
    stxt=""
    if s>1600:
        stxt=txt[0:800]+"\n\n(ry..)\n"
        st=txt[s-800:].find("\n")
        if st>0:
            stxt=stxt+txt[s-800+st:]
    else:
        stxt=txt
    txtw="\n####"+log_title+"####\n"+stxt
    f.write(txtw.encode('utf-8'))
    f.close()

==> rec10%200.9.7.tar.bz2: rec10 0.9.7/rec10/recdblist.py <==
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009-2010 Yukikaze

"""
task names
"""
import datetime
import os
import os.path

global REC_RESERVE
global REC_FINAL_RESERVE
global REC_ENCODE_GRID
global REC_ENCODE_LOCAL
global REC_ENCODE_QUE
global REC_MISS_ENCODE
global REC_KEYWORD
global REC_KEYWORD_EVERY_SOME_DAYS
global REC_FIN_LOCAL
global REC_MISS_DECODE
global REC_TS_DECODE_QUE
global REC_TS_DECODING
global REC_TS_RECORDING
global REC_AVI_TO_MKV
global REC_AVI_TO_MP4
global REC_MKV_TO_MP4
global REC_CHANGING_CANTAINER

#ここから処理のちに移動

global REC_MOVE_END

#ここから自動で提起される処理。
global REC_AUTO_SUGGEST_REC
global REC_AUTO_SUGGEST_DECODE
global REC_AUTO_SUGGEST_ENCODE
global REC_AUTO_SUGGEST_AVI2MP4
global REC_AUTO_SUGGEST_MKV2MP4
global REC_AUTO_SUGGEST_AVI2FP
global REC_AUTO_SUGGEST_AP2FP
global REC_BAYES_SUGGEST
global REC_AUTO_KEYWORD
REC_RESERVE = "reserve_flexible"
REC_FINAL_RESERVE = "reserve_fixed"
REC_ENCODE_GRID = "convert_ts_mp4_network"
REC_ENCODE_LOCAL = "convert_ts_mp4_running"
REC_ENCODE_QUE = "convert_ts_mp4"
REC_MISS_ENCODE = "convert_avi_mp4_miss"
REC_KEYWORD = "search_today"
REC_KEYWORD_EVERY_SOME_DAYS = "search_everyday"
REC_FIN_LOCAL = "convert_ts_mp4_finished"
REC_MISS_DECODE = "convert_b25_ts_miss"
REC_TS_DECODE_QUE = "convert_b25_ts"
REC_TS_DECODING = "convert_b25_ts_running"
REC_TS_RECORDING = "reserve_running"
REC_CHANGING_CANTAINER = "convert_mkv_mp4_runnings"
REC_AVI_TO_MKV = "convert_avi_mkv"
REC_AVI_TO_MP4 = "convert_avi_mp4"
REC_MKV_TO_MP4 = "convert_mkv_mp4"

REC_MOVE_END = "move_end"

REC_AUTO_SUGGEST_REC = "auto_suggest_rec"
REC_AUTO_SUGGEST_DECODE = "auto_suggest_dec"
REC_AUTO_SUGGEST_ENCODE = "auto_suggest_enc"
REC_AUTO_SUGGEST_AVI2FP = "auto_suggest_avi2fp"
REC_AUTO_SUGGEST_AP2FP = "auto_suggest_ap2fp"
REC_AUTO_KEYWORD = "auto_keyword"
REC_BAYES_SUGGEST ="bayes_suggest"

version = 96
version_str="0.9.6"
def printutf8(unicode):
    str=unicode.encode('utf-8')
    print str
def printuft8ex(unicode):
    str=unicode.encode('utf-8')
    print str
    logfname="/var/log/rec10"
    mode="a"
    if os.path.exists(logfname):
        f=open(logfname,mode)
        f.write(str+"\n")
        f.close()
def Commonlogex(type,place,inst,txt=""):
    lt=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")+u":"
    if txt=="":
        lt=lt+u"["+type+u"] "+place+u" "+inst
    else:
        lt=lt+u"["+type+u"] "+place+u" "+inst+u"\n"+txt
    lt=lt.encode('utf-8')
    logfname="/var/log/rec10"
    mode="a"
    print lt
    if os.path.exists(logfname):
        f=open(logfname,mode)
        f.write(lt+"\n")
        f.close()
def addCommandLog(tspath,log_title,cmd,cmd_log=""):
    addlog(tspath,cmd,log_title+u"ログ-コマンド")
    addlog(tspath,cmd_log,log_title+u"ログ-詳細")
def addlog(tspath,txt,log_title):
    logo=tspath
    logo=logo.replace("_1.wav",".ts")
    logo=logo.replace("_2.wav",".ts")
    logo=logo.replace("_1.aac",".ts")
    logo=logo.replace("_2.aac",".ts")
    logo=logo.replace("_1.mp3",".ts")
    logo=logo.replace("_2.mp3",".ts")
    logo=logo.replace(".ts.tsmix",".ts")
    logo=logo.replace(".ts.b25",".ts")
    logo=logo.replace(".sa.avi",".ts")
    logo=logo.replace(".m2v",".ts")
    logo=logo.replace(".avi",".ts")
    logo=logo.replace(".mkv",".ts")
    logo=logo.replace(".wav",".ts")
    logo=logo.replace(".mp4",".ts")
    logo=logo.replace(".mp3",".ts")
    logo=logo.replace(".aac",".ts")
    logo=logo.replace(".srt",".ts")
    logo=logo.replace(".ts",".log")
    f=open(logo,'a')
    s=len(txt)
    stxt=""
    if s>1600:
        stxt=txt[0:800]+"\n\n(ry..)\n"
        st=txt[s-800:].find("\n")
        if st>0:
            stxt=stxt+txt[s-800+st:]
    else:
        stxt=txt
    txtw= datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
    txtw=txtw+"\n####"+log_title+"####\n"+stxt
    f.write(txtw.encode('utf-8'))
    f.close()
